@@ -150,11 +150,11 @@ class Tools:
         self._handled_req(method='PUT', uri=f'{SB_PROXY_CHATMEDIA}/v3/group_channels/{channel_url}/hide',
                           headers={'Session-Key': session_key}, data=data)
 
-    def get_older_messages(self, channel_url, message_ts, prev_limit, reverse, session_key):
+    def get_older_messages(self, channel_url, message_ts, prev_limit, next_limit, reverse, session_key):
         params = {
             'is_sdk': 'true',
             'prev_limit': prev_limit,
-            'next_limit': '0',
+            'next_limit': next_limit,
             'include': 'false',
             'reverse': reverse,
             'message_ts': message_ts,
