@@ -12,8 +12,17 @@ class Events:
         self.on_any(frame_type=FrameType.MESG)(func)
 
     def on_ready(self, func: _hook) -> None:
-        if self.WebSocketClient.last_err is None:
-            self.on_any(frame_type=FrameType.LOGI)(func)
+        def hook(resp: FrameModel) -> Optional[bool]:
+            try:
+                _ = resp.error
+                return
+            except AttributeError:
+                pass
+            if self.WebSocketClient.last_err is not None:
+                return
+            return func(resp)
+
+        self.on_any(frame_type=FrameType.LOGI)(hook)
 
     def on_user_read(self, func: _hook) -> None:
         self.on_any(frame_type=FrameType.READ)(func)
@@ -22,7 +31,7 @@ class Events:
         def on_frame_hook_append(func: _hook):
             def hook(resp: FrameModel):
                 if resp.type_f == frame_type:
-                    func(resp)
+                    return func(resp)
 
             self.WebSocketClient.after_message_hooks.append(hook)
 
@@ -37,21 +46,22 @@ class Events:
                 return
             if not (len(invte) == 1 and invte[0] == self.WebSocketClient.own_name):
                 return
-            func(resp)
+            return func(resp)
 
         self.on_any(frame_type=FrameType.SYEV)(hook)
 
     def on_message_deleted(self, func: _hook) -> None:
         self.on_any(frame_type=FrameType.DELM)(func)
 
-    def on_user_joined(self, func: _hook):
+    def on_user_joined(self, func: _hook) -> None:
         def hook(resp: FrameModel) -> Optional[bool]:
             try:
                 _ = resp.data.users[0].nickname
                 _ = resp.data.users[0].inviter.nickname
             except (AttributeError, IndexError):
                 return
-            func(resp)
+            return func(resp)
+
         self.on_any(FrameType.SYEV)(hook)
 
     def on_user_left(self, func: _hook) -> None:
@@ -61,7 +71,8 @@ class Events:
                 _ = resp.data.nickname
             except AttributeError:
                 return
-            func(resp)
+            return func(resp)
+
         self.on_any(FrameType.SYEV)(hook)
 
     def on_user_typing(self, func: _hook) -> None:
@@ -72,5 +83,6 @@ class Events:
                 return
             if resp.cat != 10900:
                 return
-            func(resp)
+            return func(resp)
+
         self.on_any(FrameType.SYEV)(hook)
