@@ -1,8 +1,8 @@
-MOBILE_USERAGENT = 'Reddit/Version 2020.47.0/Build 302202/Android 11'
+MOBILE_USERAGENT = 'Reddit/Version 2021.20.0/Build 326964/Android 11'
 WEB_USERAGENT = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:85.0) Gecko/20100101 Firefox/85.0'
 OAUTH_CLIENT_ID_B64 = "b2hYcG9xclpZdWIxa2c6"
-USER_AGENT = 'Jand/3.0.82'
-SB_User_Agent = 'Android%2Fc3.0.144F'
+USER_AGENT = 'Jand/3.0.144'
+SB_User_Agent = 'Android%2Fc3.0.144'
 SB_ai = '2515BDA8-9D3A-47CF-9325-330BC37ADA13'
 SB_PROXY_CHATMEDIA = 'https://sendbirdproxyk8s.chat.redditmedia.com'
 S_REDDIT = 'https://s.reddit.com'
