@@ -5,7 +5,7 @@ from ._utils.frame_model import get_frame_data, FrameType
 import logging
 from threading import Thread
 from ._utils import ws_utils
-from ._utils.consts import MESG_regular, MESG_snoo, TPST, TPEN, MOBILE_USERAGENT
+from ._utils.consts import MESG_regular, MESG_snoo, MESG_gif, TPST, TPEN, USER_AGENT
 
 logging.basicConfig(level=logging.INFO, datefmt='%H:%M', format='%(asctime)s, %(levelname)s: %(message)s')
 
@@ -16,17 +16,8 @@ def _print_chat_(resp, channelid_sub_pairs):
 
 class WebSockClient:
     def __init__(self, access_token, user_id, get_current_channels, enable_trace=False, print_chat=True,
-                 log_websocket_frames=False, other_logging=True, global_blacklist_users=None,
-                 global_blacklist_words=None):
+                 log_websocket_frames=False, other_logging=True):
         self._user_id = user_id
-        if global_blacklist_words is None:
-            global_blacklist_words = set()
-        if global_blacklist_users is None:
-            global_blacklist_users = set()
-        assert isinstance(global_blacklist_words, set), "blacklists must be set()s"
-        assert isinstance(global_blacklist_users, set), "blacklists must be set()s"
-        self.global_blacklist_words = global_blacklist_words
-        self.global_blacklist_users = global_blacklist_users
 
         self.channelid_sub_pairs = {}
         self.RateLimiter = RateLimiter
@@ -57,13 +48,10 @@ class WebSockClient:
                                     on_error=self.on_error,
                                     on_close=self.on_close,
                                     on_open=self.on_open,
-                                    header={'User-Agent': MOBILE_USERAGENT}
+                                    header={'User-Agent': USER_AGENT, 'Accept-Encoding': 'gzip'}
                                     )
         return ws
 
-    def ws_run_forever(self, skip_utf8_validation):
-        self.ws.run_forever(ping_interval=15, ping_timeout=5, skip_utf8_validation=skip_utf8_validation)
-
     def update_ws_app_urls_access_token(self, access_token):
         self.ws.url = ws_utils.get_ws_url(self._user_id, access_token)
 
@@ -80,9 +68,6 @@ class WebSockClient:
             self.logger.info(message)
             self._logi(resp)
 
-        if resp.type_f == FrameType.MESG and resp.user.name in self.global_blacklist_users:
-            return
-
         Thread(target=self._response_loop, args=(resp,), daemon=True).start()
 
     def _logi(self, resp):
@@ -122,8 +107,6 @@ class WebSockClient:
     def ws_send_message(self, text, channel_url):
         if self.RateLimiter.is_enabled and self.RateLimiter.check():
             return
-        if any(blacklist_word in text.lower() for blacklist_word in self.global_blacklist_words):
-            return
         payload = MESG_regular.format(channel_url=channel_url, text=text, req_id=self.req_id)
         self.ws.send(payload)
         self.req_id += 1
@@ -135,6 +118,10 @@ class WebSockClient:
         self.ws.send(payload)
         self.req_id += 1
 
+    def ws_send_gif(self, gif_url, channel_url):
+        payload = MESG_gif.format(gif_url=gif_url, channel_url=channel_url)
+        self.ws.send(payload)
+
     def ws_send_typing_indicator(self, channel_url):
         payload = TPST.format(channel_url=channel_url, time=int(time.time() * 1000))
         self.ws.send(payload)
@@ -147,5 +134,5 @@ class WebSockClient:
         self.logger.error(error)
         self.last_err = error
 
-    def on_close(self, _):
+    def on_close(self, *_):
         self.logger.warning("### websocket closed ###")
